==> haskell-cmark-gfm-0.2.6-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cmark-gfm
version:              0.2.6
visibility:           public
id:                   cmark-gfm-0.2.6-7x94qSzZ1vD2eGkljr9s16
key:                  cmark-gfm-0.2.6-7x94qSzZ1vD2eGkljr9s16
license:              BSD-3-Clause
copyright:            (C) 2015--17 John MacFarlane, (C) 2017--19 Ashe Connor
maintainer:           ashe@kivikakk.ee
author:               Asherah Connor
homepage:             https://github.com/kivikakk/cmark-gfm-hs
synopsis:             Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark-gfm libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.29.0.gfm.13) and does not require prior installation of the
    C library.

category:             Text
abi:                  6d0179a2d58612dad548129be669d61e
exposed:              True
exposed-modules:      CMarkGFM
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cmark-gfm-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cmark-gfm-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cmark-gfm-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cmark-gfm
hs-libraries:         HScmark-gfm-0.2.6-7x94qSzZ1vD2eGkljr9s16
extra-libraries:      cmark-gfm cmark-gfm-extensions
depends:              base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html:         /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmark-gfm-0.2.6-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cmark-gfm
version:              0.2.6
visibility:           public
id:                   cmark-gfm-0.2.6-Cpeg1YOAnrKSRFNhxtV9u
key:                  cmark-gfm-0.2.6-Cpeg1YOAnrKSRFNhxtV9u
license:              BSD-3-Clause
copyright:            (C) 2015--17 John MacFarlane, (C) 2017--19 Ashe Connor
maintainer:           ashe@kivikakk.ee
author:               Asherah Connor
homepage:             https://github.com/kivikakk/cmark-gfm-hs
synopsis:             Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark-gfm libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.29.0.gfm.13) and does not require prior installation of the
    C library.

category:             Text
abi:                  2aa7179b859d8124bfd3d80ae9e561dd
exposed:              True
exposed-modules:      CMarkGFM
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cmark-gfm-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cmark-gfm-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cmark-gfm-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cmark-gfm
hs-libraries:         HScmark-gfm-0.2.6-Cpeg1YOAnrKSRFNhxtV9u
extra-libraries:      cmark-gfm cmark-gfm-extensions
depends:              base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html:         /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
